IDFlowActiveLivenessConfig class

Android only. iOS has no active-liveness config yet — on iOS only the IDFlowFaceConfig.useActiveLiveness flag is honored.

Constructors

IDFlowActiveLivenessConfig({IDFlowActiveLivenessUiVariant? uiVariant, double? targetDistanceRatio, double? headAngleLeft, double? headAngleRight, double? headAngleUp, double? headAngleDown, int? challengeTimeoutMs, int? challengeHoldTimeoutMs, bool? microphoneEnabled, bool? exitConfirmationEnabled, String? videoFilePath})
const
IDFlowActiveLivenessConfig.fromJson(Map<String, dynamic> json)
factory

Properties

challengeHoldTimeoutMs → int?
final
challengeTimeoutMs → int?
final
exitConfirmationEnabled → bool?
final
hashCode → int
The hash code for this object.
no setterinherited
headAngleDown → double?
final
headAngleLeft → double?
final
headAngleRight → double?
final
headAngleUp → double?
final
microphoneEnabled → bool?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
targetDistanceRatio → double?
final
uiVariant → IDFlowActiveLivenessUiVariant?
final
videoFilePath → String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited