IDFlowConfig class
Constructors
- IDFlowConfig({IDFlowLocale? locale, IDFlowEntryMode? entryMode, IDFlowCameraSelector? cameraSelector, IDFlowScreenOrientation? screenOrientation, IDFlowTransformation? transformation, IDFlowPreviewConfig? previewConfig, IDFlowDocumentConfig? documentConfig, IDFlowFaceConfig? faceConfig, IDFlowVideoConfig? videoConfig, bool? debugEnabled})
-
const
-
IDFlowConfig.fromJson(Map<
String, dynamic> json) -
factory
Properties
- cameraSelector → IDFlowCameraSelector?
-
final
- debugEnabled → bool?
-
final
- documentConfig → IDFlowDocumentConfig?
-
final
- entryMode → IDFlowEntryMode?
-
final
- faceConfig → IDFlowFaceConfig?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- locale → IDFlowLocale?
-
final
- previewConfig → IDFlowPreviewConfig?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- screenOrientation → IDFlowScreenOrientation?
-
final
- transformation → IDFlowTransformation?
-
final
- videoConfig → IDFlowVideoConfig?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited