IDFlowDocumentResult class

Constructors

IDFlowDocumentResult({String? pinfl, String? document, String? lastName, String? firstName, String? birthDate, String? expiryDate, String? countryCode, String? mrz})
const
IDFlowDocumentResult.fromJson(Map<String, dynamic> json)
factory

Properties

birthDate → String?
final
countryCode → String?
final
document → String?
final
expiryDate → String?
final
firstName → String?
final
hashCode → int
The hash code for this object.
no setterinherited
lastName → String?
final
mrz → String?
final
pinfl → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited