IDFlowFaceConfig class

Constructors

IDFlowFaceConfig({double? targetDistanceRatio, double? faceCropPaddingRatio, bool? useVideoIdentification, bool? progressIndicatorEnabled, bool? reasonMessageEnabled, bool? countdownEnabled, String? infoboxText})
const
IDFlowFaceConfig.fromJson(Map<String, dynamic> json)
factory

Properties

countdownEnabled bool?
final
faceCropPaddingRatio double?
final
hashCode int
The hash code for this object.
no setterinherited
infoboxText String?
final
progressIndicatorEnabled bool?
final
reasonMessageEnabled bool?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
targetDistanceRatio double?
final
useVideoIdentification bool?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited