IDFlowFieldResult class

Constructors

IDFlowFieldResult({String? front, String? back, double? match})
const
IDFlowFieldResult.fromJson(Map<String, dynamic> json)
factory

Properties

back String?
final
front String?
final
hashCode int
The hash code for this object.
no setterinherited
match double?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited