IDFlowIOSAppearance class
Constructors
- IDFlowIOSAppearance({IDFlowIOSAppAppearance? app, IDFlowIOSDocumentAppearance? document, IDFlowIOSFaceAppearance? face, IDFlowIOSVideoAppearance? video})
-
const
-
IDFlowIOSAppearance.fromJson(Map<
String, dynamic> json) -
factory
Properties
- app → IDFlowIOSAppAppearance?
-
final
- document → IDFlowIOSDocumentAppearance?
-
final
- face → IDFlowIOSFaceAppearance?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- video → IDFlowIOSVideoAppearance?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited