IDFlowIOSVideoAppearance class
Constructors
- IDFlowIOSVideoAppearance({String? success, String? error, String? loading, String? progressIndicator, String? progressTrack, String? stepDetectFocusedBackground, String? stepDetectFocusedForeground, String? stepFinishedBackground, String? stepFinishedForeground, String? stepMovingFocusedBackground, String? stepMovingFocusedForeground, String? stepMovingUnfocusedBackground, String? stepMovingUnfocusedForeground})
-
const
-
IDFlowIOSVideoAppearance.fromJson(Map<
String, dynamic> json) -
factory
Properties
- error → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- loading → String?
-
final
- progressIndicator → String?
-
final
- progressTrack → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stepDetectFocusedBackground → String?
-
final
- stepDetectFocusedForeground → String?
-
final
- stepFinishedBackground → String?
-
final
- stepFinishedForeground → String?
-
final
- stepMovingFocusedBackground → String?
-
final
- stepMovingFocusedForeground → String?
-
final
- stepMovingUnfocusedBackground → String?
-
final
- stepMovingUnfocusedForeground → String?
-
final
- success → String?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited