IDFlowEntryMode enum
Values
- fullIdent → const IDFlowEntryMode
- selfieThenDocument → const IDFlowEntryMode
- selfieWithDocument → const IDFlowEntryMode
- documentOnly → const IDFlowEntryMode
- selfieOnly → const IDFlowEntryMode
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → String -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fromJson(
dynamic value) → IDFlowEntryMode?
Constants
-
values
→ const List<
IDFlowEntryMode> - A constant List of the values in this enum, in order of their declaration.