IDFlowDocumentConfig class

Constructors

IDFlowDocumentConfig({IDFlowDocumentUiVariant? uiVariant, bool? isResident, bool? detectDocumentDuringSelfie, bool? countdownEnabled, bool? flashlightEnabled, bool? instructionEnabled})
const
IDFlowDocumentConfig.fromJson(Map<String, dynamic> json)
factory

Properties

countdownEnabled bool?
final
detectDocumentDuringSelfie bool?
final
flashlightEnabled bool?
final
hashCode int
The hash code for this object.
no setterinherited
instructionEnabled bool?
final
isResident bool?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
uiVariant IDFlowDocumentUiVariant?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited