IDFlowFaceConfig class

Constructors

IDFlowFaceConfig({double? targetDistanceRatio, double? faceCropPaddingRatio, bool? useVideoIdentification, bool? progressIndicatorEnabled, bool? reasonMessageEnabled, bool? countdownEnabled, String? infoboxText, bool? useActiveLiveness, bool? soundGuidesEnabled, bool? exitConfirmationEnabled, bool? occlusionDetectionEnabled})
const
IDFlowFaceConfig.fromJson(Map<String, dynamic> json)
factory

Properties

countdownEnabled → bool?
final
exitConfirmationEnabled → bool?
Android only.
final
faceCropPaddingRatio → double?
final
hashCode → int
The hash code for this object.
no setterinherited
infoboxText → String?
final
occlusionDetectionEnabled → bool?
Android only.
final
progressIndicatorEnabled → bool?
final
reasonMessageEnabled → bool?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
soundGuidesEnabled → bool?
Android only.
final
targetDistanceRatio → double?
final
useActiveLiveness → bool?
Routes the selfie step to the active-liveness screen (head-movement challenges) when useVideoIdentification is false.
final
useVideoIdentification → bool?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited