IDFlowIOSDocumentAppearance class
Constructors
- IDFlowIOSDocumentAppearance({String? primary, String? onPrimary, String? outline, String? divider, String? backgroundInstruction, String? foregroundInstruction})
-
const
-
IDFlowIOSDocumentAppearance.fromJson(Map<
String, dynamic> json) -
factory
Properties
- backgroundInstruction → String?
-
final
- divider → String?
-
final
- foregroundInstruction → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- onPrimary → String?
-
final
- outline → String?
-
final
- primary → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited