IDFlowIOSFaceAppearance class

Constructors

IDFlowIOSFaceAppearance({String? success, String? error, String? textMessage, String? textCountdown, String? loading, String? backgroundInfo, String? foregroundInfo, String? strokeInfo})
const
IDFlowIOSFaceAppearance.fromJson(Map<String, dynamic> json)
factory

Properties

backgroundInfo String?
final
error String?
final
foregroundInfo String?
final
hashCode int
The hash code for this object.
no setterinherited
loading String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
strokeInfo String?
final
success String?
final
textCountdown String?
final
textMessage String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited