IDFlowResult class
Constructors
- IDFlowResult({IDFlowDocumentResult? documentResult, IDFlowDocumentResult? editableDocumentResult, String? personalNumber, String? idSeriesNumber, IDFlowFieldResult? tin, IDFlowFieldResult? passport, String? selfie, String? selfieWithDocument, String? documentFace, String? documentFront, String? documentBack, String? faceData, String? videoUrl, bool? isFaceOccluded})
-
const
-
IDFlowResult.fromJson(Map<
String, dynamic> json) -
factory
Properties
- documentBack → String?
-
final
- documentFace → String?
-
final
- documentFront → String?
-
final
- documentResult → IDFlowDocumentResult?
-
final
- editableDocumentResult → IDFlowDocumentResult?
-
final
- faceData → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- idSeriesNumber → String?
-
final
- isFaceOccluded → bool?
-
final
- passport → IDFlowFieldResult?
-
final
- personalNumber → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- selfie → String?
-
final
- selfieWithDocument → String?
-
final
- tin → IDFlowFieldResult?
-
final
- videoUrl → String?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited