IDFlowVideoConfig class
Constructors
- IDFlowVideoConfig({IDFlowVideoUiVariant? uiVariant, bool? microphoneEnabled, bool? soundGuidesEnabled, bool? countdownEnabled, bool? exitConfirmationEnabled})
-
const
-
IDFlowVideoConfig.fromJson(Map<
String, dynamic> json) -
factory
Properties
- countdownEnabled → bool?
-
final
- exitConfirmationEnabled → bool?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- microphoneEnabled → bool?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- soundGuidesEnabled → bool?
-
final
- uiVariant → IDFlowVideoUiVariant?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited